/*
 * zap.h -- externs for zap program.
 * $Id: zap.h,v 1.4 2002/03/06 00:37:53 ian Exp $
 */

#if	1
#define	PS_ALL	"ps -ax"	/* UNIX, BSD */
#else
#define	PS_ALL	"ps ae" /* System V */
#endif

void die(char *fmt, void *arg);		/* print error (& errno str), then exit */
FILE *efopen(char *file, char *mode);	/* fopen file, die if can't */
void error(char *fmt, void *arg);		/* print warning (& errno str) */
extern int ttyin();	/* process response from /dev/tty (version 2) */
extern int signame(char *name);	/* name to number */
void warn(char *fmt, void *arg);	/* warning but not exit */
